@@ -23,7 +23,7 @@
 void RegisterTests()
 {
   REGISTER_TEST(otbConvolutionImageFilter);
-#if defined(ITK_USE_FFTWD)
+#if defined(OTB_USE_FFTW)
   REGISTER_TEST(otbOverlapSaveConvolutionImageFilter);
   REGISTER_TEST(otbCompareOverlapSaveAndClassicalConvolutionWithGaborFilter);
 #endif
